@@ -4,6 +4,7 @@ import time
 from .log import get_logger
 from .daemon import daemon_start
 import os
+import subprocess
 
 try:
     logger = get_logger('/tmp/bt_panel.log',3)
@@ -41,9 +42,8 @@ def func():
                 f.write(file_data)
                 log("panelPlugin.py 破解成功")
                 # 重启面板
-                print('panelPlugin.py----重启面板')
                 try:
-                    os.system("/etc/init.d/bt restart")
+                    subprocess.Popen(["/etc/init.d/bt", "restart"],stdout=subprocess.PIPE)
                 except:
                     pass
 
@@ -73,14 +73,13 @@ def func():
             with open(file, "w", encoding="utf-8") as f:
                 f.write(file_data)
                 log("total_main.py 破解成功")
-                print('total_main.py----重启面板')
                 # 重启面板
                 try:
-                    os.system("/etc/init.d/bt restart")
+                    subprocess.Popen(["/etc/init.d/bt", "restart"],stdout=subprocess.PIPE)
                 except:
                     pass
     except Exception as e :
-        print('请手动安装网站监控报表')
+        pass
         log("需要安装付费插件如：网站监控报表")
 
 
@@ -104,10 +103,9 @@ def func():
             with open(file, "w", encoding="utf-8") as f:
                 f.write(file_data)
             log("config.py 破解成功")
-            print('config.py----重启面板')
             # 重启面板
             try:
-                os.system("/etc/init.d/bt restart")
+                subprocess.Popen(["/etc/init.d/bt", "restart"], stdout=subprocess.PIPE)
             except:
                 pass
     except Exception as e:
